@@ -40,13 +40,13 @@ using Banshee.Playlist;
 
 namespace Banshee.Gui
 {
-    public class GlobalActions : BansheeActionGroup
+    public class GlobalActions : BansheeActionGroup, IGlobalUIActions
     {
-        public GlobalActions (InterfaceActionService actionService) : base (actionService, "Global")
+        public GlobalActions () : base ("Global")
         {
             Add (new ActionEntry [] {
                 // Media Menu
-                new ActionEntry ("MediaMenuAction", null, 
+                new ActionEntry ("MediaMenuAction", null,
                     Catalog.GetString ("_Media"), null, null, null),
 
                 new ActionEntry ("ImportAction", Stock.Open,
@@ -54,137 +54,137 @@ namespace Banshee.Gui
                     Catalog.GetString ("Import media from a variety of sources"), OnImport),
 
                 new ActionEntry ("ImportPlaylistAction", null,
-                    Catalog.GetString ("Import Playlist..."), null,
+                    Catalog.GetString ("Import _Playlist..."), null,
                     Catalog.GetString ("Import a playlist"), OnImportPlaylist),
 
-                new ActionEntry ("OpenLocationAction", null, 
+                new ActionEntry ("RescanAction", null,
+                    Catalog.GetString ("Rescan Music Library"), null,
+                    Catalog.GetString ("Rescan the Music Library folder"), delegate {
+                        new Banshee.Collection.RescanPipeline (ServiceManager.SourceManager.MusicLibrary);
+                    }),
+
+                new ActionEntry ("OpenLocationAction", null,
                     Catalog.GetString ("Open _Location..."), "<control>L",
                     Catalog.GetString ("Open a remote location for playback"), OnOpenLocation),
-                    
+
                 new ActionEntry ("QuitAction", Stock.Quit,
                     Catalog.GetString ("_Quit"), "<control>Q",
                     Catalog.GetString ("Quit Banshee"), OnQuit),
 
                 // Edit Menu
-                new ActionEntry ("EditMenuAction", null, 
+                new ActionEntry ("EditMenuAction", null,
                     Catalog.GetString("_Edit"), null, null, null),
 
                 new ActionEntry ("PreferencesAction", Stock.Preferences,
                     Catalog.GetString ("_Preferences"), null,
                     Catalog.GetString ("Modify your personal preferences"), OnPreferences),
 
-                new ActionEntry ("ExtensionsAction", null, 
+                new ActionEntry ("ExtensionsAction", null,
                     Catalog.GetString ("Manage _Extensions"), null,
                     Catalog.GetString ("Manage extensions to add new features to Banshee"), OnExtensions),
-                
+
                 // Tools menu
                 new ActionEntry ("ToolsMenuAction", null,
                     Catalog.GetString ("_Tools"), null, null, null),
-                
+
                 // Help Menu
-                new ActionEntry ("HelpMenuAction", null, 
+                new ActionEntry ("HelpMenuAction", null,
                     Catalog.GetString ("_Help"), null, null, null),
-                
+
+                new ActionEntry ("UserHelp", Gtk.Stock.Help,
+                    Catalog.GetString ("_Contents"), "F1", null,
+                    delegate { Banshee.ServiceStack.Application.DisplayHelp (null); }),
+
                 new ActionEntry ("WebMenuAction", null,
                     Catalog.GetString ("_Web Resources"), null, null, null),
-                    
+
                 new ActionEntry ("WikiGuideAction", Stock.Help,
                     Catalog.GetString ("Banshee _User Guide (Wiki)"), null,
                     Catalog.GetString ("Learn about how to use Banshee"), delegate {
-                        Banshee.Web.Browser.Open ("http://banshee-project.org/Guide");
+                        Banshee.Web.Browser.Open ("http://banshee.fm/support/guide/");
                     }),
-                    
+
                 new ActionEntry ("WikiSearchHelpAction", null,
                     Catalog.GetString ("Advanced Collection Searching"), null,
                     Catalog.GetString ("Learn advanced ways to search your media collection"), delegate {
-                        Banshee.Web.Browser.Open ("http://banshee-project.org/OnePointEx/Search");
+                        Banshee.Web.Browser.Open ("http://banshee.fm/support/guide/searching/");
                     }),
-                    
+
                 new ActionEntry ("WikiAction", null,
                     Catalog.GetString ("Banshee _Home Page"), null,
                     Catalog.GetString ("Visit the Banshee Home Page"), delegate {
-                        Banshee.Web.Browser.Open ("http://banshee-project.org/");
+                        Banshee.Web.Browser.Open ("http://banshee.fm/");
                     }),
-                    
+
                 new ActionEntry ("WikiDeveloperAction", null,
                     Catalog.GetString ("_Get Involved"), null,
                     Catalog.GetString ("Become a contributor to Banshee"), delegate {
-                        Banshee.Web.Browser.Open ("http://banshee-project.org/Developers");
+                        Banshee.Web.Browser.Open ("http://banshee.fm/contribute/");
                     }),
-                 
+
                 new ActionEntry ("VersionInformationAction", null,
-                    Catalog.GetString ("_Version Information..."), null,
+                    Catalog.GetString ("_Version Information"), null,
                     Catalog.GetString ("View detailed version and configuration information"), OnVersionInformation),
-                    
+
                 new ActionEntry("AboutAction", "gtk-about", OnAbout)
             });
-            
+
             this["ExtensionsAction"].Visible = false;
+
+            GLib.Timeout.Add (500, delegate {
+                if (ApplicationContext.CommandLine.Contains ("show-import-media")) {
+                    OnImport (null, null);
+                }
+
+                if (ApplicationContext.CommandLine.Contains ("show-about")) {
+                    OnAbout (null, null);
+                }
+
+                if (ApplicationContext.CommandLine.Contains ("show-open-location")) {
+                    OnOpenLocation (null, null);
+                }
+
+                if (ApplicationContext.CommandLine.Contains ("show-preferences")) {
+                    OnPreferences (null, null);
+                }
+
+                return false;
+            });
         }
-            
+
 #region Media Menu Actions
 
         private void OnImport (object o, EventArgs args)
         {
-            Banshee.Library.Gui.ImportDialog dialog = new Banshee.Library.Gui.ImportDialog ();            
-            try {
-                if (dialog.Run () != Gtk.ResponseType.Ok) {
-                    return;
-                }
-                    
-                dialog.ActiveSource.Import ();
-            } finally {
-                dialog.Destroy ();
+            var dialog = new Banshee.Library.Gui.ImportDialog ();
+            var res = dialog.Run ();
+            var src = dialog.ActiveSource;
+            dialog.Destroy ();
+
+            if (res == Gtk.ResponseType.Ok) {
+                src.Import ();
             }
         }
-        
+
         private void OnOpenLocation (object o, EventArgs args)
         {
             OpenLocationDialog dialog = new OpenLocationDialog ();
             ResponseType response = dialog.Run ();
             string address = dialog.Address;
             dialog.Destroy ();
-            
-            if(response != ResponseType.Ok) {
-                return;
-            }
-            
-            try {
-                RadioTrackInfo radio_track = new RadioTrackInfo (new SafeUri (address));
-                radio_track.ParsingPlaylistEvent += delegate {
-                    if (radio_track.PlaybackError != StreamPlaybackError.None) {
-                        Log.Error (Catalog.GetString ("Error opening stream"), 
-                            Catalog.GetString ("Could not open stream or playlist"), true);
-                        radio_track = null;
-                    }
-                };
-                radio_track.Play ();
-            } catch {
-                Log.Error (Catalog.GetString ("Error opening stream"), 
-                    Catalog.GetString("Problem parsing playlist"), true);
+
+            if (response == ResponseType.Ok) {
+                RadioTrackInfo.OpenPlay (address);
             }
         }
 
         private void OnImportPlaylist (object o, EventArgs args)
         {
             // Prompt user for location of the playlist.
-            Banshee.Gui.Dialogs.FileChooserDialog chooser = new Banshee.Gui.Dialogs.FileChooserDialog (
-                Catalog.GetString("Import Playlist"),
-                PrimaryWindow,
-                FileChooserAction.Open
-            );
-                         
-            chooser.DefaultResponse = ResponseType.Ok;
-            chooser.SelectMultiple = true;
+            var chooser = Banshee.Gui.Dialogs.FileChooserDialog.CreateForImport (Catalog.GetString("Import Playlist"), true);
             chooser.AddFilter (Hyena.Gui.GtkUtilities.GetFileFilter (Catalog.GetString ("Playlists"), PlaylistFileUtil.PlaylistExtensions));
-            try {
-                chooser.AddShortcutFolder (Paths.LibraryLocation);
-            } catch {}
 
-            chooser.AddButton (Stock.Cancel, ResponseType.Cancel);
-            chooser.AddButton (Catalog.GetString("Import"), ResponseType.Ok);
-            
-            int response = chooser.Run();            
+            int response = chooser.Run();
 
             string [] uris = null;
             if (response == (int) ResponseType.Ok) {
@@ -194,21 +194,23 @@ namespace Banshee.Gui
                 chooser.Destroy();
                 return;
             }
-            
+
             if (uris == null || uris.Length == 0) {
                 return;
             }
-            
-            foreach (string uri in uris) {
-                PlaylistFileUtil.ImportPlaylistToLibrary (uri);
-            }
+
+            Banshee.Kernel.Scheduler.Schedule (new Banshee.Kernel.DelegateJob (delegate {
+                foreach (string uri in uris) {
+                    PlaylistFileUtil.ImportPlaylistToLibrary (uri);
+                }
+            }));
         }
-        
+
         private void OnQuit (object o, EventArgs args)
         {
             Banshee.ServiceStack.Application.Shutdown ();
         }
-        
+
 #endregion
 
 #region Edit Menu Actions
@@ -229,24 +231,55 @@ namespace Banshee.Gui
         }
 
 #endregion
-        
+
 #region Help Menu Actions
-        
+
         private void OnVersionInformation (object o, EventArgs args)
         {
             Hyena.Gui.Dialogs.VersionInformationDialog dialog = new Hyena.Gui.Dialogs.VersionInformationDialog ();
             dialog.Run ();
             dialog.Destroy ();
         }
-        
+
         private void OnAbout (object o, EventArgs args)
         {
             Banshee.Gui.Dialogs.AboutDialog dialog = new Banshee.Gui.Dialogs.AboutDialog ();
-            dialog.Run ();
-            dialog.Destroy ();
+            dialog.Show ();
         }
 
 #endregion
-            
+
+#region IGlobalUIActions
+
+        void IGlobalUIActions.ShowImportDialog ()
+        {
+            Gtk.Application.Invoke (OnImport);
+        }
+
+        void IGlobalUIActions.ShowAboutDialog ()
+        {
+            Gtk.Application.Invoke (OnAbout);
+        }
+
+        void IGlobalUIActions.ShowOpenLocationDialog ()
+        {
+            Gtk.Application.Invoke (OnOpenLocation);
+        }
+
+        void IGlobalUIActions.ShowPreferencesDialog ()
+        {
+            Gtk.Application.Invoke (OnPreferences);
+        }
+
+        IDBusExportable IDBusExportable.Parent {
+            get { return null; }
+        }
+
+        string IService.ServiceName {
+            get { return "GlobalUIActions"; }
+        }
+
+#endregion
+
     }
 }
